@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "elfeed-score" "1.2.11"
+(define-package "elfeed-score" "20251012.2253"
   "Gnus-style scoring for Elfeed."
   '((emacs  "26.1")
     (elfeed "3.3.0"))
   :url "https://github.com/sp1ff/elfeed-score"
-  :commit "f6ef83c472e6f01d0f60130ecac768462c5a20b7"
-  :revdesc "1.2.11-0-gf6ef83c472e6"
+  :commit "9e9874dc4f2a6b01199e0834ba52665d8383ad9f"
+  :revdesc "9e9874dc4f2a"
   :keywords '("news")
   :authors '(("Michael Herstine" . "sp1ff@pobox.com"))
   :maintainers '(("Michael Herstine" . "sp1ff@pobox.com")))
